==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/AmbReceiver__5fc.h <==
// public class polyglot.ext.jl.ast.AmbReceiver_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f30a43253e995b polyglot_ext_jl_ast_AmbPrefix__5fc
// @dep_class 38d15f9b90abc140 polyglot_ext_jl_ast_AmbReceiver__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AmbPrefix__5fc

#include "polyglot/ext/jl/ast/AmbPrefix__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_
#define _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_AmbReceiver$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_Prefix$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_AmbiguityRemover$object;
struct _jc_polyglot_visit_TypeBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$_init$761a8a111923c70e(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$buildTypes$df90664105e3e235(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$disambiguate$d149e043dfa73b41(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_AmbiguityRemover$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$type$50d9b16f7484c0bc(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$buildTypes$df90664105e3e235;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$disambiguate$d149e043dfa73b41;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$type$b7282830a20ab2a3;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$type$50d9b16f7484c0bc;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods {
	struct _jc_object	*(*buildTypes$df90664105e3e235)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *);
	struct _jc_object	*(*disambiguate$d149e043dfa73b41)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_AmbiguityRemover$object *);
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *);
	struct _jc_object	*(*type$50d9b16f7484c0bc)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_AmbPrefix__5fc$vmethods	polyglot_ext_jl_ast_AmbPrefix__5fc;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods	polyglot_ext_jl_ast_AmbReceiver__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs {
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs {
    _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs	polyglot_ext_jl_ast_AmbReceiver__5fc;
    _jc_polyglot_ext_jl_ast_AmbPrefix__5fc$sub_refs	polyglot_ext_jl_ast_AmbPrefix__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_AmbPrefix__5fc$sub_nonrefs	polyglot_ext_jl_ast_AmbPrefix__5fc;
    _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs	polyglot_ext_jl_ast_AmbReceiver__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object {
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_AmbReceiver__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/AmbReceiver__5fc.h <==
// public class polyglot.ext.jl.ast.AmbReceiver_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f30a43253e995b polyglot_ext_jl_ast_AmbPrefix__5fc
// @dep_class 38d15f9b90abc140 polyglot_ext_jl_ast_AmbReceiver__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AmbPrefix__5fc

#include "polyglot/ext/jl/ast/AmbPrefix__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_
#define _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_AmbReceiver$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_Prefix$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_AmbiguityRemover$object;
struct _jc_polyglot_visit_TypeBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$_init$761a8a111923c70e(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$buildTypes$df90664105e3e235(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$disambiguate$d149e043dfa73b41(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_AmbiguityRemover$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method$type$50d9b16f7484c0bc(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$buildTypes$df90664105e3e235;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$disambiguate$d149e043dfa73b41;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$type$b7282830a20ab2a3;
extern _jc_method _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$method_info$type$50d9b16f7484c0bc;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods {
	struct _jc_object	*(*buildTypes$df90664105e3e235)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*disambiguate$d149e043dfa73b41)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_polyglot_visit_AmbiguityRemover$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*type$50d9b16f7484c0bc)(_jc_env *, struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_AmbPrefix__5fc$vmethods	polyglot_ext_jl_ast_AmbPrefix__5fc;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vmethods	polyglot_ext_jl_ast_AmbReceiver__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs {
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs {
    _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_refs	polyglot_ext_jl_ast_AmbReceiver__5fc;
    _jc_polyglot_ext_jl_ast_AmbPrefix__5fc$sub_refs	polyglot_ext_jl_ast_AmbPrefix__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_AmbPrefix__5fc$sub_nonrefs	polyglot_ext_jl_ast_AmbPrefix__5fc;
    _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$sub_nonrefs	polyglot_ext_jl_ast_AmbReceiver__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$object {
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_AmbReceiver__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$vtype _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_AmbReceiver__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_AmbReceiver__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_AmbReceiver__5fc_H_ */
